@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -139,11 +139,9 @@ extern WandExport MagickBooleanType
     const ChannelType, const MetricType,double *),
   MagickGetImageDistortion(MagickWand *,const MagickWand *,const MetricType,
     double *),
-  MagickGetImageChannelExtrema(MagickWand *,const ChannelType,unsigned long *,
-    unsigned long *),
   MagickGetImageChannelMean(MagickWand *,const ChannelType,double *,double *),
+  MagickGetImageChannelRange(MagickWand *,const ChannelType,double *,double *),
   MagickGetImageColormapColor(MagickWand *,const unsigned long,PixelWand *),
-  MagickGetImageExtrema(MagickWand *,unsigned long *,unsigned long *),
   MagickGetImageGreenPrimary(MagickWand *,double *,double *),
   MagickGetImageMatte(MagickWand *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
@@ -153,6 +151,7 @@ extern WandExport MagickBooleanType
   MagickGetImagePixelColor(MagickWand *,const long,const long,PixelWand *),
   MagickGetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,void *),
+  MagickGetImageRange(MagickWand *,double *,double *),
   MagickGetImageRedPrimary(MagickWand *,double *,double *),
   MagickGetImageResolution(MagickWand *,double *,double *),
   MagickGetImageWhitePoint(MagickWand *,double *,double *),
@@ -256,8 +255,10 @@ extern WandExport MagickBooleanType
   MagickSetImageMatte(MagickWand *,const MagickBooleanType),
   MagickSetImageMatteColor(MagickWand *,const PixelWand *),
   MagickSetImageOpacity(MagickWand *,const double),
+  MagickSetImageOrientation(MagickWand *,const OrientationType),
   MagickSetImagePage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
+  MagickResetImagePage(MagickWand *,const char *),
   MagickSetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,const void *),
   MagickSetImageProfile(MagickWand *,const char *,const void *,const size_t),
@@ -266,7 +267,7 @@ extern WandExport MagickBooleanType
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
   MagickSetImageScene(MagickWand *,const unsigned long),
-  MagickSetImageTicksPerSecond(MagickWand *,const unsigned long),
+  MagickSetImageTicksPerSecond(MagickWand *,const long),
   MagickSetImageType(MagickWand *,const ImageType),
   MagickSetImageUnits(MagickWand *,const ResolutionType),
   MagickSetImageWhitePoint(MagickWand *,const double,const double),
@@ -345,6 +346,9 @@ extern WandExport MagickWand
   *MagickTransformImage(MagickWand *,const char *,const char *),
   *NewMagickWandFromImage(const Image *);
 
+extern WandExport OrientationType
+  MagickGetImageOrientation(MagickWand *);
+
 extern WandExport PixelWand
   **MagickGetImageHistogram(MagickWand *,unsigned long *);
 
@@ -376,38 +380,6 @@ extern WandExport unsigned long
 extern WandExport VirtualPixelMethod
   MagickGetImageVirtualPixelMethod(MagickWand *);
 
-/*
-  Deprecated methods.
-*/
-extern WandExport char
-  *MagickDescribeImage(MagickWand *),
-  *MagickGetImageAttribute(MagickWand *,const char *);
-
-extern WandExport long
-  MagickGetImageIndex(MagickWand *);
-
-extern WandExport MagickBooleanType
-  MagickOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
-    const double),
-  MagickSetImageAttribute(MagickWand *,const char *,const char *),
-  MagickSetImageIndex(MagickWand *,const long),
-  MagickSetImageOption(MagickWand *,const char *,const char *,const char *),
-  MagickTransparentImage(MagickWand *,const PixelWand *,const double,
-    const double);
-
-extern WandExport MagickWand
-  *MagickRegionOfInterestImage(MagickWand *,const unsigned long,
-    const unsigned long,const long,const long);
-
-extern WandExport MagickSizeType
-  MagickGetImageSize(MagickWand *);
-
-extern WandExport unsigned char
-  *MagickWriteImageBlob(MagickWand *,size_t *);
-
-extern WandExport VirtualPixelMethod
-  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod);
-
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
